---
blogged: None
category: None
comments: true
date: None
description: None
footer: None
imagefeature: m51.jpg
layout: post
link: None
modified: None
otherlocations: None
private: false
tags: []
title: admin
type: photo|video|status|quote|link
wiki: testwiki1
---
<!--summary-->

# Admin Pages

## Top Level Includes

* [[Sidebar|/_Sidebar]]
* [[Footer|/_Footer]]
* [[Header|/_Header]]

## Project Page Includes

* [[Sidebar|/projects/_Sidebar]]
* [[Footer|/projects/_Footer]]
* [[Header|/projects/_Header]] 

## Pages to Process

* [[untagged pages|http://wiki2.thespacedoctor.co.uk/search?q=%23untagged]]
* [[pages to send to blog?|http://wiki2.thespacedoctor.co.uk/search?q=%23not-blogged]]